#
# BJones module for simulating a simple slope across the bandpass
# Errors can also be applied via the same method as the GJones.
#
# ianh / oms 
# June 2009
#
#% $Id$ 
#
#
# Copyright (C) 2002-2007
# The MeqTree Foundation & 
# ASTRON (Netherlands Foundation for Research in Astronomy)
# P.O.Box 2, 7990 AA Dwingeloo, The Netherlands
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>,
# or write to the Free Software Foundation, Inc., 
# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
# 
#

from Timba.TDL import *
from Meow import Context

import random
import math
from Siamese.OMS import ErrorGens

DEG = math.pi/180.;
ARCMIN = DEG/60;
ARCSEC = DEG/3600;

def compute_jones (Jones,stations=None,**kw):
  stations = stations or Context.array.stations();
  
  slopegen = _slope_errgen.node_maker();
  
  for p in stations:
    Jj = Jones(p);
    ns = Jj.Subscope();
    
    slopegen(ns.xslope,station=p);
    slopegen(ns.yslope,station=p);
    
    ns.xa << ns.xslope*(Meq.Freq() - Context.observation.freq0())/(Context.observation.freq1() - Context.observation.freq0());
    ns.ya << ns.yslope*(Meq.Freq() - Context.observation.freq0())/(Context.observation.freq1() - Context.observation.freq0());
    
    Jj << Meq.Matrix22(
      ns.xa,0,0,ns.ya
    );
    
  return Jones;

_slope_errgen = ErrorGens.Selector("slope",1,[.5,1.5]);

TDLCompileOptions(*_slope_errgen.options());
